/* -----------------------------------------------------------------------
 *	Copylight(C) 2018 Kanazawa-soft-design,LLC.
 * ----------------------------------------------------------------------- */
/*!
 *	@file	AboutDialog.java
 *
 *	@brief	バージョン情報ダイアログ.
 *
 *	@author	金澤 宣明
 */
package sample.JavaSwing001;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

@SuppressWarnings("serial")
public class AboutDialog extends JDialog implements ActionListener  {

	/* ----------------------------------------------------------------------- */
	/**
	 *	コンストラクタ.
	 *
	 *	@param	owner	ダイアログの所有者(親ウインドウ).
	 *	@param	modal	true = モーダル･ダイアログ.
	 */
	AboutDialog( JFrame owner, boolean modal ) {

		super( owner, modal );

		//!「閉じる」ボタンにイベントを登録する.
		setDefaultCloseOperation( WindowConstants.DISPOSE_ON_CLOSE );

		//! ダイアログのサイズを設定する.
		setSize( 300, 200 );

		//! ダイアログのタイトルをセットする.
		setTitle( "バージョン情報 JavaSwing001" );

		//! レイアウト･マネージャーは使わない.
		Container contentPane = getContentPane();
		contentPane.setLayout( null );

		//! バージョンをダイアログに配置する.
		JLabel label1 = new JLabel( "JavaFX001, Version 1.0" );
		label1.setBounds( 16, 16, 200, 16 );
		contentPane.add( label1 );

		//! 著作権表記をダイアログに配置する.
		JLabel label2 = new JLabel( "Copyright (C) 2018 金澤ソフト設計" );
		label2.setBounds( 16, 32, 200, 16 );
		contentPane.add( label2 );

		//! OKボタンをダイアログに配置する.
		JButton btn = new JButton( "OK" );
		btn.addActionListener( this );
		btn.setBounds( 110, 120, 60, 30 );
		contentPane.add( btn );

		//! ダイアログの表示位置を画面の中央にする.
		setLocation( (Toolkit.getDefaultToolkit().getScreenSize().width)  / 2 - getWidth()  / 2,
					 (Toolkit.getDefaultToolkit().getScreenSize().height) / 2 - getHeight() / 2);

		//! ダイアログのサイズ変更が出来ないようにする.
		setResizable( false );
	}

	/* ----------------------------------------------------------------------- */
	/**
	 *	OKボタンを押下したときのイベント処理.
	 *
	 *	@param	e		イベント･パラメータ.
	 */
	public void actionPerformed( ActionEvent e ) {

		//! ダイアログを閉じる.
		this.dispose();
	}
}

/* End of file */
